@@ -3,8 +3,6 @@
 #include <libguile.h>
 #include <numeric>
 
-extern "C"
-{
 #include <config.h>
 
 #include <qof.h>
@@ -13,7 +11,6 @@ extern "C"
 #include "gnc-engine-guile.h"
 #include "gnc-guile-utils.h"
 #include "gnc-kvp-guile.h"
-}
 
 /* NOTE: There are some problems with this approach. Currently,
  *       guids are stored simply as strings in scheme, so some
@@ -124,7 +121,7 @@ gnc_kvp_value_ptr_to_scm(KvpValue* val)
     case KvpValue::Type::GUID:
     {
         auto tempguid = val->get<GncGUID*>();
-        return gnc_guid2scm(*tempguid);
+        return tempguid ? gnc_guid2scm(*tempguid) : SCM_BOOL_F;
     }
     break;
     case KvpValue::Type::FRAME:
@@ -136,7 +133,7 @@ gnc_kvp_value_ptr_to_scm(KvpValue* val)
             auto val_scm { gnc_kvp_value_ptr_to_scm (iter.second) };
             return scm_acons (key_scm, val_scm, rv);
         };
-        return scm_reverse (std::accumulate (frame->begin(), frame->end(), SCM_EOL, acc));
+        return frame ? scm_reverse (std::accumulate (frame->begin(), frame->end(), SCM_EOL, acc)) : SCM_BOOL_F;
     }
     break;
     case KvpValue::Type::GLIST:
