@@ -115,19 +115,19 @@ def invoice_to_lco(invoice):
     add_str = u""
     owner = invoice.GetOwner()
     if owner.GetName() != "":
-        add_str += owner.GetName().decode("UTF-8") + "\n"
+        add_str += owner.GetName() + "\n"
 
     addr = owner.GetAddr()
     if addr.GetName() != "":
-        add_str += addr.GetName().decode("UTF-8") + "\n"
+        add_str += addr.GetName() + "\n"
     if addr.GetAddr1() != "":
-        add_str += addr.GetAddr1().decode("UTF-8") + "\n"
+        add_str += addr.GetAddr1() + "\n"
     if addr.GetAddr2() != "":
-        add_str += addr.GetAddr2().decode("UTF-8") + "\n"
+        add_str += addr.GetAddr2() + "\n"
     if addr.GetAddr3() != "":
-        add_str += addr.GetAddr3().decode("UTF-8") + "\n"
+        add_str += addr.GetAddr3() + "\n"
     if addr.GetAddr4() != "":
-        add_str += addr.GetAddr4().decode("UTF-8") + "\n"
+        add_str += addr.GetAddr4() + "\n"
 
     lco_out += write_variable("toaddress2", add_str)
 
@@ -147,7 +147,7 @@ def invoice_to_lco(invoice):
 
     # Write the entries
     ent_str = u""
-    locale.setlocale(locale.LC_ALL, "de_DE")
+    locale.setlocale(locale.LC_ALL, "")
     for n, ent in enumerate(invoice.GetEntries()):
 
         line_str = u""
@@ -160,14 +160,14 @@ def invoice_to_lco(invoice):
         n = ent.GetQuantity()
 
         uprice = locale.currency(price).rstrip(" EUR")
-        un = unicode(
+        un = str(
             int(float(n.num()) / n.denom())
         )  # choose best way to format numbers according to locale
 
         line_str = u"\Artikel{"
         line_str += un
         line_str += u"}{"
-        line_str += descr.decode("UTF-8")
+        line_str += descr
         line_str += u"}{"
         line_str += uprice
         line_str += u"}"
@@ -288,7 +288,6 @@ def main(argv=None):
 
         # Opening output file
         f = open(output_file_name, "w")
-        lco_str = lco_str.encode("latin1")
         f.write(lco_str)
         f.close()
 
