@@ -35,17 +35,20 @@
 #include "gnc-file.h"
 #include "gnc-features.h"
 #include "gnc-filepath-utils.h"
+#include "gnc-glib-utils.h"
 #include "gnc-gui-query.h"
 #include "gnc-hooks.h"
 #include "gnc-keyring.h"
 #include "gnc-splash.h"
 #include "gnc-ui.h"
+#include "gnc-ui-balances.h"
 #include "gnc-ui-util.h"
 #include "gnc-uri-utils.h"
 #include "gnc-window.h"
 #include "gnc-plugin-file-history.h"
 #include "qof.h"
 #include "Scrub.h"
+#include "ScrubBudget.h"
 #include "TransLog.h"
 #include "gnc-session.h"
 #include "gnc-state.h"
@@ -692,6 +695,20 @@ gnc_file_query_save (GtkWindow *parent, gboolean can_cancel)
 }
 
 
+
+static char*
+get_account_sep_warning (QofBook *book)
+{
+    const char *sep = gnc_get_account_separator_string ();
+    GList *violation_accts = gnc_account_list_name_violations (book, sep);
+    if (!violation_accts)
+        return NULL;
+
+    gchar *rv = gnc_account_name_violations_errmsg (sep, violation_accts);
+    g_list_free_full (violation_accts, g_free);
+    return rv;
+}
+
 /* private utilities for file open; done in two stages */
 
 #define RESPONSE_NEW 1
@@ -700,12 +717,54 @@ gnc_file_query_save (GtkWindow *parent, gboolean can_cancel)
 #define RESPONSE_READONLY 4
 #define RESPONSE_FILE 5
 
+/* This function is called after loading datafile. It's meant to
+   collect all scrubbing routines. */
+static void
+run_post_load_scrubs (GtkWindow *parent, QofBook *book)
+{
+    const char *budget_warning =
+        _("This book has budgets. The internal representation of "
+          "budget amounts no longer depends on the Reverse Balanced "
+          "Accounts preference. Please review the budgets and amend "
+          "signs if necessary.");
+
+    GList *infos = NULL;
+
+    qof_event_suspend();
+
+    /* If feature GNC_FEATURE_BUDGET_UNREVERSED is not set, and there
+       are budgets, fix signs */
+    if (gnc_maybe_scrub_all_budget_signs (book))
+        infos = g_list_prepend (infos, g_strdup (budget_warning));
+
+    // Fix account color slots being set to 'Not Set', should run once on a book
+    xaccAccountScrubColorNotSet (book);
+
+    /* Check for account names that may contain the current separator character
+     * and inform the user if there are any */
+    char *sep_warning = get_account_sep_warning (book);
+    if (sep_warning)
+        infos = g_list_prepend (infos, sep_warning);
+
+    qof_event_resume();
+
+    if (!infos)
+        return;
+
+    const char *header = N_("The following are noted in this file:");
+    infos = g_list_reverse (infos);
+    infos = g_list_prepend (infos, g_strdup (_(header)));
+    char *final = gnc_g_list_stringjoin (infos, "\n\n• ");
+    gnc_info_dialog (parent, "%s", final);
+
+    g_free (final);
+    g_list_free_full (infos, g_free);
+}
+
 static gboolean
 gnc_post_file_open (GtkWindow *parent, const char * filename, gboolean is_readonly)
 {
     QofSession *new_session;
-    QofBook *new_book;
-    GList *invalid_account_names;
     gboolean uh_oh = FALSE;
     char * newfile;
     QofBackendError io_err = ERR_BACKEND_NO_ERR;
@@ -947,7 +1006,7 @@ RESTART:
                                        path, username, password );
 
         xaccLogDisable();
-        gnc_window_show_progress(_("Loading user data..."), 0.0);
+        gnc_window_show_progress(_("Loading user data…"), 0.0);
         qof_session_load (new_session, gnc_window_show_progress);
         gnc_window_show_progress(NULL, -1.0);
         xaccLogEnable();
@@ -967,7 +1026,7 @@ RESTART:
             if (gnc_xml_convert_single_file (newfile))
             {
                 /* try to load once again */
-                gnc_window_show_progress(_("Loading user data..."), 0.0);
+                gnc_window_show_progress(_("Loading user data…"), 0.0);
                 qof_session_load (new_session, gnc_window_show_progress);
                 gnc_window_show_progress(NULL, -1.0);
                 xaccLogEnable();
@@ -983,7 +1042,7 @@ RESTART:
         /* Attempt to update the database if it's too old */
         if ( !uh_oh && io_err == ERR_SQL_DB_TOO_OLD )
         {
-            gnc_window_show_progress(_("Re-saving user data..."), 0.0);
+            gnc_window_show_progress(_("Re-saving user data…"), 0.0);
             qof_session_safe_save(new_session, gnc_window_show_progress);
             io_err = qof_session_get_error(new_session);
             uh_oh = show_session_error(parent, io_err, newfile, GNC_FILE_DIALOG_SAVE);
@@ -1089,24 +1148,7 @@ RESTART:
     /* Call this after re-enabling events. */
     gnc_book_opened ();
 
-    /* Check for account names that may contain the current separator character
-     * and inform the user if there are any */
-    new_book = gnc_get_current_book();
-    invalid_account_names = gnc_account_list_name_violations ( new_book,
-                            gnc_get_account_separator_string() );
-    if ( invalid_account_names )
-    {
-        gchar *message = gnc_account_name_violations_errmsg ( gnc_get_account_separator_string(),
-                         invalid_account_names );
-        gnc_warning_dialog(parent, "%s", message);
-        g_free ( message );
-        g_list_free_full (invalid_account_names, g_free);
-    }
-
-    // Fix account color slots being set to 'Not Set', should run once on a book
-    qof_event_suspend();
-    xaccAccountScrubColorNotSet (gnc_get_current_book());
-    qof_event_resume();
+    run_post_load_scrubs (parent, gnc_get_current_book ());
 
     return TRUE;
 }
@@ -1346,7 +1388,7 @@ gnc_file_do_export(GtkWindow *parent, const char * filename)
 
     /* use the current session to save to file */
     gnc_set_busy_cursor (NULL, TRUE);
-    gnc_window_show_progress(_("Exporting file..."), 0.0);
+    gnc_window_show_progress(_("Exporting file…"), 0.0);
     ok = qof_session_export (new_session, current_session,
                              gnc_window_show_progress);
     gnc_window_show_progress(NULL, -1.0);
@@ -1406,7 +1448,7 @@ gnc_file_save (GtkWindow *parent)
     /* use the current session to save to file */
     save_in_progress++;
     gnc_set_busy_cursor (NULL, TRUE);
-    gnc_window_show_progress(_("Writing file..."), 0.0);
+    gnc_window_show_progress(_("Writing file…"), 0.0);
     qof_session_save (session, gnc_window_show_progress);
     gnc_window_show_progress(NULL, -1.0);
     gnc_unset_busy_cursor (NULL);
@@ -1645,7 +1687,7 @@ gnc_file_do_save_as (GtkWindow *parent, const char* filename)
 
 
     gnc_set_busy_cursor (NULL, TRUE);
-    gnc_window_show_progress(_("Writing file..."), 0.0);
+    gnc_window_show_progress(_("Writing file…"), 0.0);
     qof_session_save (new_session, gnc_window_show_progress);
     gnc_window_show_progress(NULL, -1.0);
     gnc_unset_busy_cursor (NULL);
