@@ -225,7 +225,7 @@ void
 gnc_customer_import_gui_help_cb (GtkWidget *widget, gpointer data)
 {
     CustomerImportGui *gui = data;
-    gnc_gnome_help (GTK_WINDOW(gui->dialog), HF_GUIDE, HL_IMPORT_CUST);
+    gnc_gnome_help (GTK_WINDOW(gui->dialog), DF_GUIDE, DL_IMPORT_CUST);
 }
 
 static void
