@@ -109,9 +109,7 @@ static char *olds;
    returning a 0 length valid string between two consecutive ocurence of delim.
    It will also return a 0 length string instead of NULL when it reaches the end of s
 */
-static char * my_strtok (s, delim)
-char *s;
-const char *delim;
+static char * my_strtok (char *s, const char *delim)
 {
     char *token;
     /*DEBUG("strtok(): Start...");*/
@@ -235,12 +233,12 @@ static split_record interpret_split_record( char *record_line)
     }
     if (strlen(tok_ptr = my_strtok(NULL, "\t")) != 0)
     {
-        string_to_gnc_numeric(tok_ptr, &(record.amount));
+        record.amount = gnc_numeric_from_string (tok_ptr);
         record.amount_present = TRUE;
     }
     if (strlen(tok_ptr = my_strtok(NULL, "\t")) != 0)
     {
-        string_to_gnc_numeric(tok_ptr, &(record.value));
+        record.value = gnc_numeric_from_string (tok_ptr);
         record.value_present = TRUE;
     }
     if (strlen(tok_ptr = my_strtok(NULL, "\t")) != 0)
@@ -367,7 +365,6 @@ static void  process_trans_record(  FILE *log_file)
     const char * record_end_str = "===== END";
     int first_record = TRUE;
     int record_ended = FALSE;
-    int split_num = 0;
     split_record record;
     Transaction * trans = NULL;
     Split * split = NULL;
@@ -382,7 +379,6 @@ static void  process_trans_record(  FILE *log_file)
         if (read_retval != NULL &&
             strncmp(record_end_str, read_buf, strlen(record_end_str)) != 0) /* If we are not at the end of the record */
         {
-            split_num++;
             /*DEBUG("process_trans_record(): Line read: %s%s",read_buf ,"\n");*/
 
             record = interpret_split_record(g_strchomp(read_buf));
