@@ -408,13 +408,13 @@ also show overall period profit & loss."))
            (lp rest
                (let ((converted (and show-orig-cur? convert-curr-fn
                                      (convert-curr-fn monetary col-datum))))
-                 (cons* (gnc:html-markup-br)
-                        (if anchor
+                 (cons* (if anchor
                             (gnc:html-markup-anchor anchor (or converted monetary))
                             (or converted monetary))
                         (if converted
                             (gnc:html-markup-i (gnc:html-markup "small" monetary " "))
                             "")
+                        (if (null? accum) "" (gnc:html-markup-br))
                         accum)))))))
 
   (define (account->depth acc)
@@ -739,12 +739,7 @@ also show overall period profit & loss."))
          ;; generate an exchange-fn for date, and cache its result.
          (get-date-exchange-fn
           (let ((h (make-hash-table))
-                (commodities (sort-and-delete-duplicates
-                              (map xaccAccountGetCommodity accounts)
-                              (lambda (a b)
-                                (gnc:string-locale<? (gnc-commodity-get-unique-name a)
-                                                     (gnc-commodity-get-unique-name b)))
-                              gnc-commodity-equal)))
+                (commodities (gnc:accounts-get-commodities accounts #f)))
             (lambda (date)
               (or (hashv-ref h date)
                   (let ((exchangefn (gnc:case-exchange-time-fn
