@@ -130,13 +130,6 @@
   (make-link-blank)
   link-blank?)
 
-(define-record-type :payment-info
-  (make-payment-info overpayment invoices opposing-splits)
-  payment-info?
-  (overpayment payment-info-overpayment)
-  (invoices payment-info-invoices)
-  (opposing-splits payment-info-opposing-splits))
-
 ;; Names in Option panel (Untranslated! Because it is used for option
 ;; naming and lookup only, and the display of the option name will be
 ;; translated somewhere else.)
@@ -193,18 +186,15 @@
 
 (define (build-column-used options)
   (define (opt-val name)
-    (gnc:option-value
-     (gnc:lookup-option options "Display Columns" name)))
+    (gnc-optiondb-lookup-value options "Display Columns" name))
   (list->vector
    (map opt-val
         (list date-header due-date-header reference-header type-header
               desc-header sale-header tax-header debit-header credit-header
               balance-header doclink-header))))
 
-(define (make-heading-list column-vector link-option acct-type)
-  (let ((heading-list '())
-        (formal? (gnc-prefs-get-bool GNC-PREFS-GROUP-GENERAL
-                                     GNC-PREF-ACCOUNTING-LABELS)))
+(define (make-heading-list column-vector link-option)
+  (let ((heading-list '()))
     (if (date-col column-vector)
         (addto! heading-list (G_ date-header)))
     (if (date-due-col column-vector)
@@ -222,15 +212,9 @@
     (if (tax-col column-vector)
         (addto! heading-list (G_ tax-header)))
     (if (debit-col column-vector)
-        (addto! heading-list
-                (if formal?
-                    (G_ debit-header)
-                    (gnc-account-get-debit-string acct-type))))
+        (addto! heading-list (G_ debit-header)))
     (if (credit-col column-vector)
-        (addto! heading-list
-                (if formal?
-                    (G_ credit-header)
-                    (gnc-account-get-credit-string acct-type))))
+        (addto! heading-list (G_ credit-header)))
     (if (bal-col column-vector)
         (addto! heading-list (G_ balance-header)))
     (case link-option
@@ -301,14 +285,16 @@
 
 ;; input: list of html-text elements
 ;; output: a cell with html-text interleaved with <br> tags
-(define (list->cell lst)
+(define* (list->cell lst #:optional skip-empty?)
   (let lp ((lst lst) (result '()))
     (match lst
       (() (apply gnc:make-html-text result))
+      (("" . rest) (=> fail) (if skip-empty? (lp rest result) (fail)))
       ((elt . rest) (lp rest (cons* elt (gnc:html-markup-br) result))))))
 
-(define (splits->desc splits)
-  (list->cell (map (compose gnc:html-string-sanitize xaccSplitGetMemo) splits)))
+(define* (splits->desc splits #:optional skip-empty?)
+  (list->cell (map (compose gnc:html-string-sanitize xaccSplitGetMemo) splits)
+              skip-empty?))
 
 (define (make-aging-table splits to-date payable? date-type currency)
   (let ((table (gnc:make-html-table))
@@ -483,6 +469,8 @@
   (define mid-span
     (if (eq? link-option 'detailed) (num-cols used-columns 'mid-spac) 0))
 
+  (define add-derived-amounts-disclaimer? #f)
+
   (define (split->anchor split negate?)
     (gnc:html-markup-anchor
      (gnc:split-anchor-text split)
@@ -513,8 +501,13 @@
           (addif (debit-col used-columns)  (make-cell debit))
           (addif (credit-col used-columns) (make-cell credit))
           (addif (bal-col used-columns)    (make-cell total))
-          (addif (< 0 rhs-cols) (gnc:make-html-table-cell/size
-                                 1 (+ mid-span rhs-cols) #f)))))
+          (addif (< 0 rhs-cols)
+                 (gnc:make-html-table-cell/size
+                  1 (+ mid-span rhs-cols)
+                  (and add-derived-amounts-disclaimer?
+                       (gnc:make-html-text
+                        (G_ "* Amounts denoted thus are derived from, \
+and do not match the transaction."))))))))
 
     ;; print grand total
     (if (bal-col used-columns)
@@ -610,9 +603,9 @@
                                (split->reference lot-split)
                                (split->type-str lot-split payable?)
                                (splits->desc non-document)
-                               (gnc:make-html-text (split->anchor lot-split #t))
+                               (gnc:make-html-text (split->anchor lot-split #f))
                                (list->cell
-                                (map (lambda (s) (split->anchor s #f)) non-document))
+                                (map (lambda (s) (split->anchor s #t)) non-document))
                                (gncTransGetGUID lot-txn))
                               result))))
 
@@ -628,8 +621,7 @@
                 (lambda (posting-split)
                   (let* ((lot-txn-split (car lot-txn-splits))
                          (posting-txn (xaccSplitGetParent posting-split))
-                         (document (gncInvoiceGetInvoiceFromTxn posting-txn))
-                         (neg (gncInvoiceGetIsCreditNote document)))
+                         (document (gncInvoiceGetInvoiceFromTxn posting-txn)))
                     (lp1 (cdr lot-txn-splits)
                          non-document
                          (cons (make-link-data
@@ -637,8 +629,8 @@
                                 (split->reference posting-split)
                                 (split->type-str posting-split payable?)
                                 (splits->desc (list posting-split))
-                                (gnc:make-html-text (split->anchor lot-split neg))
-                                (gnc:make-html-text (split->anchor posting-split neg))
+                                (gnc:make-html-text (split->anchor lot-split #f))
+                                (gnc:make-html-text (split->anchor posting-split #f))
                                 (gncInvoiceReturnGUID document))
                                result)))))
 
@@ -649,34 +641,6 @@
                      (cons (car lot-txn-splits) non-document)
                      result))))))))))
 
-
-
-  (define (payment-txn->payment-info txn)
-    (let lp ((splits (xaccTransGetAPARAcctSplitList txn #f))
-             (overpayment 0)
-             (invoices '())
-             (opposing-splits '()))
-      (match splits
-        (() (make-payment-info (AP-negate overpayment) invoices opposing-splits))
-        ((split . rest)
-         (let ((lot (xaccSplitGetLot split)))
-           (define (equal-to-split? s) (equal? s split))
-           (match (gncInvoiceGetInvoiceFromLot lot)
-             (() (let lp1 ((lot-splits (gnc-lot-get-split-list lot))
-                           (opposing-splits opposing-splits))
-                   (match lot-splits
-                     (() (lp rest
-                             (- overpayment (gnc-lot-get-balance lot))
-                             invoices
-                             opposing-splits))
-                     (((? equal-to-split?) . tail) (lp1 tail opposing-splits))
-                     ((head . tail) (lp1 tail (cons head opposing-splits))))))
-             (inv
-              (lp rest
-                  overpayment
-                  (cons (cons inv split) invoices)
-                  opposing-splits))))))))
-
   (define (make-payment->invoices-list txn)
     (list
      (list
@@ -685,17 +649,15 @@
        (map
         (lambda (inv-split-pair)
           (invoice->anchor (car inv-split-pair)))
-        (payment-info-invoices (payment-txn->payment-info txn)))))))
+        (vector-ref (gnc:payment-txn->payment-info txn) 0))))))
 
-  (define (make-payment->payee-table txn)
+  (define (make-payment->payee-table txn payable?)
 
-    (define payment-info (payment-txn->payment-info txn))
-
-    (define invoices-list
-      (let lp ((invoice-split-pairs (payment-info-invoices payment-info))
+    (define (invoices-list invoice-split-pairs)
+      (let lp ((invoice-split-pairs invoice-split-pairs)
                (result '()))
         (match invoice-split-pairs
-          (() result)
+          (() (reverse result))
           (((inv . APAR-split) . rest)
            (let* ((posting-split (lot-split->posting-split APAR-split)))
              (lp rest
@@ -709,29 +671,47 @@
                         (gncInvoiceReturnGUID inv))
                        result)))))))
 
-    (define overpayment-list
-      (let ((overpayment (payment-info-overpayment payment-info)))
-        (if (zero? overpayment)
-            '()
-            (list (make-link-desc-amount
-                   (G_ "Pre-Payment")
-                   (gnc:make-gnc-monetary currency overpayment)
-                   (gncTransGetGUID txn))))))
+    (define (payments-list opposing-splits)
+      (let lp1 ((opposing-splits opposing-splits)
+                (pmt-list '()))
+        (match opposing-splits
+          (() (reverse pmt-list))
+          (((s partial-amount derived?). rest)
+           (when derived?
+             (set! add-derived-amounts-disclaimer? #t))
+           (lp1 rest
+                (cons
+                 (make-link-data
+                  (qof-print-date (xaccTransGetDate (xaccSplitGetParent s)))
+                  (split->reference s)
+                  (split->type-str s payable?)
+                  (splits->desc (list s))
+                  (gnc:make-html-text
+                   (if derived? "* " "")
+                   (gnc:html-markup-anchor
+                    (gnc:split-anchor-text s)
+                    (gnc:monetary->string
+                     (gnc:make-gnc-monetary currency partial-amount))))
+                  (gnc:make-html-text (split->anchor s #f))
+                  (gncTransGetGUID (xaccSplitGetParent s)))
+                 pmt-list))))))
 
-    (define payments-list
-      (map
-       (lambda (s)
-         (make-link-data
-          (qof-print-date (xaccTransGetDate (xaccSplitGetParent s)))
-          (split->reference s)
-          (split->type-str s payable?)
-          (splits->desc (list s))
-          (gnc:make-html-text (split->anchor s #f))
-          (gnc:make-html-text (split->anchor s #f))
-          (gncTransGetGUID (xaccSplitGetParent s))))
-       (payment-info-opposing-splits payment-info)))
+    (define (overpayment-list overpayment)
+      (if (zero? overpayment)
+          '()
+          (list (make-link-desc-amount
+                 (G_ "Pre-Payment")
+                 (gnc:make-html-text
+                  (gnc:monetary->string
+                   (gnc:make-gnc-monetary
+                    currency ((if payable? + -) overpayment))))
+                 (gncTransGetGUID txn)))))
 
-    (append invoices-list payments-list overpayment-list))
+    (let* ((payment-info (gnc:payment-txn->payment-info txn))
+           (invoices-result (invoices-list (vector-ref payment-info 0)))
+           (payment-result (payments-list (vector-ref payment-info 1)))
+           (overpayment-result (overpayment-list (vector-ref payment-info 2))))
+      (append invoices-result payment-result overpayment-result)))
 
   (define (amount->anchor split amount)
     (gnc:make-html-text
@@ -739,6 +719,8 @@
       (gnc:split-anchor-text split)
       (gnc:make-gnc-monetary currency amount))))
 
+  (define seen-txns (make-hash-table))
+
   (let lp ((printed? #f)
            (odd-row? #t)
            (splits splits)
@@ -764,6 +746,9 @@
        'attribute (list "cellpadding" 4))
       table)
 
+     ((hash-ref seen-txns (xaccSplitGetParent (car splits)))
+      (lp printed? odd-row? (cdr splits) invalid-splits total debit credit tax sale))
+
      ;; not an invoice/payment. skip transaction.
      ((not (or (txn-is-invoice? (xaccSplitGetParent (car splits)))
                (txn-is-payment? (xaccSplitGetParent (car splits)))))
@@ -785,6 +770,7 @@
      ((< (xaccTransGetDate (xaccSplitGetParent (car splits))) start-date)
       (let* ((txn (xaccSplitGetParent (car splits)))
              (value (AP-negate (xaccTransGetAccountAmount txn acc))))
+        (hash-set! seen-txns txn #t)
         (lp printed? odd-row? (cdr splits) invalid-splits (+ total value)
             debit credit tax sale)))
 
@@ -797,6 +783,7 @@
 
      ;; start printing txns.
      ((txn-is-invoice? (xaccSplitGetParent (car splits)))
+      (hash-set! seen-txns (xaccSplitGetParent (car splits)) #t)
       (let* ((split (car splits))
              (txn (xaccSplitGetParent split))
              (date (xaccTransGetDate txn))
@@ -831,17 +818,25 @@
             (+ sale (CN-negate gncInvoiceGetTotalSubtotal)))))
 
      ((txn-is-payment? (xaccSplitGetParent (car splits)))
+      (hash-set! seen-txns (xaccSplitGetParent (car splits)) #t)
       (let* ((split (car splits))
              (txn (xaccSplitGetParent split))
              (date (xaccTransGetDate txn))
-             (orig-value (xaccTransGetAccountAmount txn acc))
+             (amt/next-pair
+              (let lp1 ((splits splits) (acc 0) (non-txn '()))
+                (match splits
+                  (() (cons acc (reverse non-txn)))
+                  (((? (lambda (s) (equal? (xaccSplitGetParent s) txn)) head) . tail)
+                   (lp1 tail (+ (xaccSplitGetAmount head) acc) non-txn))
+                  ((head . tail) (lp1 tail acc (cons head non-txn))))))
+             (orig-value (car amt/next-pair))
              (value (AP-negate orig-value)))
 
         (add-row
          table odd-row? used-columns date #f
          (split->reference split)
          (split->type-str split payable?)
-         (splits->desc (xaccTransGetAPARAcctSplitList txn #t))
+         (splits->desc (xaccTransGetAPARAcctSplitList txn #t) #t)
          #f currency (+ total value)
          (and (>= orig-value 0) (amount->anchor split orig-value))
          (and (< orig-value 0) (amount->anchor split (- orig-value)))
@@ -850,124 +845,100 @@
          link-option
          (case link-option
            ((simple) (make-payment->invoices-list txn))
-           ((detailed) (make-payment->payee-table txn))
+           ((detailed) (make-payment->payee-table txn payable?))
            (else '(()))))
 
-        (lp printed? (not odd-row?) (cdr splits) invalid-splits (+ total value)
+        (lp printed? (not odd-row?) (cdr amt/next-pair) invalid-splits (+ total value)
             (if (< 0 orig-value) (+ debit orig-value) debit)
             (if (< 0 orig-value) credit (- credit orig-value))
             tax
             sale))))))
 
 (define (options-generator owner-type)
+  (let ((options (gnc-new-optiondb)))
 
-  (define gnc:*report-options* (gnc:new-options))
-
-  (define (gnc:register-inv-option new-option)
-    (gnc:register-option gnc:*report-options* new-option))
-
-  (gnc:register-inv-option
-   (gnc:make-owner-option
+  (gnc-register-owner-option options
     owner-page (owner-string owner-type) "v"
-    (N_ "The company for this report.")
-    (lambda () '()) #f owner-type))
+    (N_ "The company for this report.") '() owner-type)
 
   (gnc:options-add-date-interval!
-   gnc:*report-options* gnc:pagename-general
+   options gnc:pagename-general
    optname-from-date optname-to-date "a")
 
   ;; Use a default report date of 'today'
-  (gnc:option-set-default-value
-   (gnc:lookup-option gnc:*report-options* gnc:pagename-general optname-to-date)
+  (GncOption-set-default-value
+   (gnc-lookup-option options gnc:pagename-general optname-to-date)
    (cons 'relative 'today))
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") date-header
-    "b" (N_ "Display the transaction date?") #t))
+    "b" (N_ "Display the transaction date?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") due-date-header
-    "c" (N_ "Display the transaction date?") #t))
+    "c" (N_ "Display the transaction date?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") reference-header
-    "d" (N_ "Display the transaction reference?") #t))
+    "d" (N_ "Display the transaction reference?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") type-header
-    "g" (N_ "Display the transaction type?") #t))
+    "g" (N_ "Display the transaction type?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") desc-header
-    "ha" (N_ "Display the transaction description?") #t))
+    "ha" (N_ "Display the transaction description?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") sale-header
-    "haa" (N_ "Display the sale amount column?") #f))
+    "haa" (N_ "Display the sale amount column?") #f)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") tax-header
-    "hab" (N_ "Display the tax column?") #f))
+    "hab" (N_ "Display the tax column?") #f)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") debit-header
-    "hac" (N_ "Display the period debits column?") #t))
+    "hac" (N_ "Display the period debits column?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") credit-header
-    "had" (N_ "Display the period credits column?") #t))
+    "had" (N_ "Display the period credits column?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") balance-header
-    "hb" (N_ "Display a running balance?") #t))
+    "hb" (N_ "Display a running balance?") #t)
 
-  (gnc:register-inv-option
-   (gnc:make-multichoice-option
+  (gnc-register-multichoice-option options
     (N_ "Display Columns") linked-txns-header
-    "hc" (N_ "Show linked transactions") 'none
-    (list (vector 'none
-                  (N_ "Disabled")
-                  (N_ "Linked transactions are hidden."))
-          (vector 'simple
-                  (N_ "Simple")
-                  (N_ "Invoices show if paid, payments show invoice numbers."))
-          (vector 'detailed
-                  (N_ "Detailed")
-                  (N_ "Invoices show list of payments, payments show list of \
-invoices and amounts.")))))
+    "hc"
+    (string-join
+     (list
+      (G_ "Show linked transactions")
+      (G_ "Linked transactions are hidden.")
+      (G_ "Invoices show if paid, payments show invoice numbers.")
+      (G_ "Invoices show list of payments, payments show list of invoices and amounts."))
+      "\n* ")
+    "none"
+    (list (vector 'none (N_ "Disabled"))
+          (vector 'simple (N_ "Simple"))
+          (vector 'detailed (N_ "Detailed"))))
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
+  (gnc-register-simple-boolean-option options
     (N_ "Display Columns") doclink-header
-    "hd" (N_ "Display document link?") #f))
+    "hd" (N_ "Display document link?") #f)
 
-  (gnc:register-inv-option
-   (gnc:make-multichoice-option
+  (gnc-register-multichoice-option options
     gnc:pagename-general optname-date-driver "k"
-    (N_ "Leading date.") 'duedate
+    (N_ "Leading date.") "duedate"
     (list
-     ;; Should be using standard label for due date?
-     (vector 'duedate
-             (N_ "Due Date")
-             (N_ "Due date is leading."))
-     ;; Should be using standard label for post date?
-     (vector 'postdate
-             (N_ "Post Date")
-             (N_ "Post date is leading.")))))
+     (vector 'duedate (N_ "Due Date"))
+     (vector 'postdate (N_ "Post Date"))))
 
-  (gnc:options-set-default-section gnc:*report-options* "General")
+  (gnc:options-set-default-section options "General")
 
-  gnc:*report-options*)
+  options))
 
 (define (setup-query q owner accounts end-date job?)
   (let ((guid (gncOwnerReturnGUID (if job? owner (gncOwnerGetEndOwner owner))))
@@ -1029,13 +1000,9 @@ invoices and amounts.")))))
 (define (reg-renderer report-obj type)
   (define options (gnc:report-options report-obj))
   (define (opt-val section name)
-    (gnc:option-value
-     (gnc:lookup-option options section name)))
+    (gnc-optiondb-lookup-value options section name))
 
-  (let* ((accounts (filter (compose xaccAccountIsAPARType xaccAccountGetType)
-                           (gnc-account-get-descendants-sorted
-                            (gnc-get-current-root-account))))
-         (start-date (gnc:time64-start-day-time
+  (let* ((start-date (gnc:time64-start-day-time
                       (gnc:date-option-absolute-time
                        (opt-val gnc:pagename-general optname-from-date))))
          (end-date (gnc:time64-end-day-time
@@ -1044,24 +1011,22 @@ invoices and amounts.")))))
          (book (gnc-get-current-book))
          (date-format (gnc:options-fancy-date (gnc-get-current-book)))
          (used-columns (build-column-used options))
-         (link-option
-          (gnc:option-value
-           (gnc:lookup-option options "Display Columns" linked-txns-header)))
+         (link-option (opt-val "Display Columns" linked-txns-header))
          (owner-descr (owner-string type))
          (date-type (opt-val gnc:pagename-general optname-date-driver))
          (owner (opt-val owner-page owner-descr))
-         (payable? (memv (gncOwnerGetType (gncOwnerGetEndOwner owner))
-                         (list GNC-OWNER-VENDOR GNC-OWNER-EMPLOYEE)))
+         (acct-type (if (eqv? (gncOwnerGetType (gncOwnerGetEndOwner owner))
+                              GNC-OWNER-CUSTOMER)
+                        ACCT-TYPE-RECEIVABLE ACCT-TYPE-PAYABLE))
+         (accounts (filter (lambda (a) (eqv? (xaccAccountGetType a) acct-type))
+                           (gnc-account-get-descendants-sorted
+                            (gnc-get-current-root-account))))
+         (payable? (eqv? ACCT-TYPE-PAYABLE acct-type))
          (query (qof-query-create-for-splits))
          (document (gnc:make-html-document))
          (table (gnc:make-html-table))
          (section-headings (make-section-heading-list used-columns owner-descr))
-         (headings (make-heading-list
-                    used-columns link-option
-                    (if (eqv? (gncOwnerGetType (gncOwnerGetEndOwner owner))
-                              GNC-OWNER-CUSTOMER)
-                        ACCT-TYPE-RECEIVABLE
-                        ACCT-TYPE-PAYABLE)))
+         (headings (make-heading-list used-columns link-option))
          (report-title (string-append (G_ owner-descr) " " (G_ "Report"))))
 
     (cond
@@ -1083,7 +1048,7 @@ invoices and amounts.")))))
      (else
       (setup-query query owner accounts end-date (eqv? GNC-OWNER-JOB type))
 
-      (let ((splits (xaccQueryGetSplitsUniqueTrans query)))
+      (let ((splits (qof-query-run query)))
         (qof-query-destroy query)
 
         (gnc:html-document-set-headline!
@@ -1233,13 +1198,12 @@ invoices and amounts.")))))
 
 
 (define (owner-report-create-internal report-guid owner owner-type enddate)
-  (let* ((options (gnc:make-report-options report-guid))
-         (owner-op (gnc:lookup-option options owner-page (owner-string owner-type)))
-         (date-op (gnc:lookup-option options gnc:pagename-general optname-to-date)))
+  (let* ((options (gnc:make-report-options report-guid)))
 
-    (gnc:option-set-value owner-op owner)
+    (gnc-set-option options owner-page (owner-string owner-type) owner)
     (when enddate
-      (gnc:option-set-value date-op (cons 'absolute enddate)))
+      (gnc-set-option options gnc:pagename-general optname-to-date
+                      (cons 'absolute enddate)))
     (gnc:make-report report-guid options)))
 
 (define (owner-report-create-with-enddate owner account enddate)
@@ -1252,20 +1216,14 @@ invoices and amounts.")))))
              (guid (assv-ref guid-alist type)))
     (owner-report-create-internal guid owner type enddate)))
 
-(define (owner-report-create owner account)
-  (owner-report-create-with-enddate owner account #f))
-
 (define (gnc:owner-report-create-internal
          account split query journal? double? title debit-string credit-string)
-
-  (let* ((owner (gnc:split->owner split))
-         (res (if (gncOwnerIsValid owner)
-                  (owner-report-create owner account)
-                  -1)))
-    (gnc:split->owner #f)
-    res))
+  (let* ((split->owner (gnc:make-split->owner))
+         (owner (split->owner split)))
+    (if (gncOwnerIsValid owner)
+        (owner-report-create-with-enddate owner account #f)
+        -1)))
 
 (gnc:register-report-hook ACCT-TYPE-RECEIVABLE #t gnc:owner-report-create-internal)
 (gnc:register-report-hook ACCT-TYPE-PAYABLE #t gnc:owner-report-create-internal)
-(export owner-report-create)
 (export owner-report-create-with-enddate)
